====================
rackspace-novaclient
====================


Metapackage to install python-novaclient and Rackspace extensions


Install
=======

::

  pip install rackspace-novaclient


Usage
=====

This metapackage will ensure that python-novaclient and these extensions
are installed that are compatible with the Rackspace cloud:

- rackspace-auth-openstack
- os_diskconfig_python_novaclient_ext
- rax_scheduled_images_python_novaclient_ext
- os_networksv2_python_novaclient_ext
- os_virtual_interfacesv2_python_novaclient_ext
- rax_default_network_flags_python_novaclient_ext
- ip_associations_python_novaclient_ext

